@@ -21,96 +21,18 @@ from heat.engine import properties
 from neutronclient.common.exceptions import NeutronClientException
 
 
-class ApplicationPolicyGroup(gbpresource.GBPResource):
-
-    PROPERTIES = (
-        TENANT_ID, NAME, DESCRIPTION, SHARED
-    ) = (
-        'tenant_id', 'name', 'description', 'shared'
-    )
-
-    properties_schema = {
-        TENANT_ID: properties.Schema(
-            properties.Schema.STRING,
-            _('Tenant id of the Application Policy Group.')
-        ),
-        NAME: properties.Schema(
-            properties.Schema.STRING,
-            _('Name of the Application Policy Group.'),
-            update_allowed=True
-        ),
-        DESCRIPTION: properties.Schema(
-            properties.Schema.STRING,
-            _('Description of the Application Policy Group.'),
-            update_allowed=True
-        ),
-        SHARED: properties.Schema(
-            properties.Schema.BOOLEAN,
-            _('Shared.'),
-            update_allowed=True, required=True
-        )
-    }
-
-    def _show_resource(self):
-        client = self.grouppolicy()
-        application_policy_group_id = self.resource_id
-        return client.show_application_policy_group(
-            application_policy_group_id)['application_policy_group']
-
-    def handle_create(self):
-        client = self.grouppolicy()
-
-        props = {}
-        for key in self.properties:
-            if self.properties.get(key) is not None:
-                props[key] = self.properties.get(key)
-
-        application_policy_group = (
-            client.create_application_policy_group(
-                {'application_policy_group':
-                 props})['application_policy_group'])
-
-        self.resource_id_set(application_policy_group['id'])
-
-    def handle_delete(self):
-
-        client = self.grouppolicy()
-        application_policy_group_id = self.resource_id
-
-        try:
-            client.delete_application_policy_group(
-                application_policy_group_id)
-        except NeutronClientException as ex:
-            self.client_plugin().ignore_not_found(ex)
-        else:
-            return self._delete_task()
-
-    def handle_update(self, json_snippet, tmpl_diff, prop_diff):
-        if prop_diff:
-            self.grouppolicy().update_application_policy_group(
-                self.resource_id, {'application_policy_group': prop_diff})
-
-
 class PolicyTarget(gbpresource.GBPResource):
 
     PROPERTIES = (
-        TENANT_ID, NAME, DESCRIPTION, POLICY_TARGET_GROUP_ID,
-        PORT_ID, FIXED_IPS
+        TENANT_ID, NAME, DESCRIPTION, POLICY_TARGET_GROUP_ID
     ) = (
-        'tenant_id', 'name', 'description', 'policy_target_group_id',
-        'port_id', 'fixed_ips'
-    )
-
-    _FIXED_IP_KEYS = (
-        FIXED_IP_SUBNET_ID, FIXED_IP_IP_ADDRESS,
-    ) = (
-        'subnet_id', 'ip_address',
+        'tenant_id', 'name', 'description', 'policy_target_group_id'
     )
 
     ATTRIBUTES = (
-        PORT_ID_ATTR, FIXED_IPS_ATTR
+        PORT_ID
     ) = (
-        'port_id', 'fixed_ips'
+        'port_id'
     )
 
     properties_schema = {
@@ -133,43 +55,13 @@ class PolicyTarget(gbpresource.GBPResource):
             _('Policy target group id of the policy target.'),
             required=True,
             update_allowed=True
-        ),
-        PORT_ID: properties.Schema(
-            properties.Schema.STRING,
-            _('Neutron port id of the policy target.'),
-            update_allowed=False
-        ),
-        FIXED_IPS: properties.Schema(
-            properties.Schema.LIST,
-            _('Desired IPs for this port.'),
-            schema=properties.Schema(
-                properties.Schema.MAP,
-                schema={
-                    FIXED_IP_SUBNET_ID: properties.Schema(
-                        properties.Schema.STRING,
-                        _('Subnet ID to associate with this interface.'),
-                    ),
-                    FIXED_IP_IP_ADDRESS: properties.Schema(
-                        properties.Schema.STRING,
-                        _('IP address desired in the subnet for this port.'),
-                        constraints=[
-                            constraints.CustomConstraint('ip_addr')
-                        ]
-                    ),
-                },
-            ),
-            update_allowed=True
-        ),
+        )
     }
 
     attributes_schema = {
-        PORT_ID_ATTR: attributes.Schema(
-            _('Neutron port id of this policy target.')
-        ),
-        FIXED_IPS_ATTR: attributes.Schema(
-            _("Fixed IP addresses."),
-            type=attributes.Schema.LIST
-        ),
+        PORT_ID: attributes.Schema(
+            _("Neutron port id of this policy target")
+        )
     }
 
     def _show_resource(self):
@@ -184,13 +76,19 @@ class PolicyTarget(gbpresource.GBPResource):
         for key in self.properties:
             if self.properties.get(key) is not None:
                 props[key] = self.properties.get(key)
-        self._prepare_port_properties(props)
 
         pt = client.create_policy_target(
             {'policy_target': props})['policy_target']
 
         self.resource_id_set(pt['id'])
 
+    def _resolve_attribute(self, name):
+        client = self.grouppolicy()
+        pt_id = self.resource_id
+        if name == 'port_id':
+            return client.show_policy_target(pt_id)['policy_target']['port_id']
+        return super(PolicyTarget, self)._resolve_attribute(name)
+
     def handle_delete(self):
 
         client = self.grouppolicy()
@@ -208,24 +106,16 @@ class PolicyTarget(gbpresource.GBPResource):
             self.grouppolicy().update_policy_target(
                 self.resource_id, {'policy_target': prop_diff})
 
-    def _prepare_port_properties(self, props):
-        for fixed_ip in props.get(self.FIXED_IPS, []):
-            for key, value in list(fixed_ip.items()):
-                if value is None:
-                    fixed_ip.pop(key)
-
 
 class PolicyTargetGroup(gbpresource.GBPResource):
 
     PROPERTIES = (
-        TENANT_ID, NAME, DESCRIPTION, APPLICATION_POLICY_GROUP_ID,
-        L2_POLICY_ID, PROVIDED_POLICY_RULE_SETS, CONSUMED_POLICY_RULE_SETS,
-        NETWORK_SERVICE_POLICY_ID, SHARED, INTRA_PTG_ALLOW
+        TENANT_ID, NAME, DESCRIPTION, L2_POLICY_ID, PROVIDED_POLICY_RULE_SETS,
+        CONSUMED_POLICY_RULE_SETS, NETWORK_SERVICE_POLICY_ID, SHARED
     ) = (
-        'tenant_id', 'name', 'description', 'application_policy_group_id',
-        'l2_policy_id', 'provided_policy_rule_sets',
-        'consumed_policy_rule_sets', 'network_service_policy_id', 'shared',
-        'intra_ptg_allow'
+        'tenant_id', 'name', 'description', 'l2_policy_id',
+        'provided_policy_rule_sets', 'consumed_policy_rule_sets',
+        'network_service_policy_id', 'shared'
     )
 
     properties_schema = {
@@ -243,11 +133,6 @@ class PolicyTargetGroup(gbpresource.GBPResource):
             _('Description of the policy target group.'),
             update_allowed=True
         ),
-        APPLICATION_POLICY_GROUP_ID: properties.Schema(
-            properties.Schema.STRING,
-            _('Application Policy Group id of the policy target group.'),
-            update_allowed=True
-        ),
         L2_POLICY_ID: properties.Schema(
             properties.Schema.STRING,
             _('L2 policy id of the policy target group.'),
@@ -272,11 +157,6 @@ class PolicyTargetGroup(gbpresource.GBPResource):
             properties.Schema.BOOLEAN,
             _('Shared.'),
             update_allowed=True, required=True
-        ),
-        INTRA_PTG_ALLOW: properties.Schema(
-            properties.Schema.BOOLEAN,
-            _('Allow or disallow intra-ptg traffic.'),
-            update_allowed=True
         )
 
     }
@@ -341,36 +221,6 @@ class PolicyTargetGroup(gbpresource.GBPResource):
 
     def handle_update(self, json_snippet, tmpl_diff, prop_diff):
         if prop_diff:
-            provided_policy_rule_set_list = {}
-            consumed_policy_rule_set_list = {}
-            props_provided_policy_rule_sets = prop_diff.get(
-                'provided_policy_rule_sets', [])
-            props_consumed_policy_rule_sets = prop_diff.get(
-                'consumed_policy_rule_sets', [])
-
-            for prop_prov_policy_rule_set in props_provided_policy_rule_sets:
-                policy_rule_set_id = (
-                    prop_prov_policy_rule_set['policy_rule_set_id'])
-                policy_rule_set_scope = (
-                    prop_prov_policy_rule_set['policy_rule_set_scope'])
-                provided_policy_rule_set_list.update({policy_rule_set_id:
-                                                      policy_rule_set_scope})
-
-            for prop_cons_policy_rule_set in props_consumed_policy_rule_sets:
-                policy_rule_set_id = (
-                    prop_cons_policy_rule_set['policy_rule_set_id'])
-                policy_rule_set_scope = (
-                    prop_cons_policy_rule_set['policy_rule_set_scope'])
-                consumed_policy_rule_set_list.update({policy_rule_set_id:
-                                                      policy_rule_set_scope})
-
-            if provided_policy_rule_set_list:
-                prop_diff['provided_policy_rule_sets'] = (
-                    provided_policy_rule_set_list)
-            if consumed_policy_rule_set_list:
-                prop_diff['consumed_policy_rule_sets'] = (
-                    consumed_policy_rule_set_list)
-
             self.grouppolicy().update_policy_target_group(
                 self.resource_id, {'policy_target_group': prop_diff})
 
@@ -378,10 +228,9 @@ class PolicyTargetGroup(gbpresource.GBPResource):
 class L2Policy(gbpresource.GBPResource):
 
     PROPERTIES = (
-        TENANT_ID, NAME, DESCRIPTION, L3_POLICY_ID, SHARED, REUSE_BD
+        TENANT_ID, NAME, DESCRIPTION, L3_POLICY_ID, SHARED
     ) = (
-        'tenant_id', 'name', 'description', 'l3_policy_id', 'shared',
-        'reuse_bd'
+        'tenant_id', 'name', 'description', 'l3_policy_id', 'shared'
     )
 
     properties_schema = {
@@ -409,11 +258,6 @@ class L2Policy(gbpresource.GBPResource):
             properties.Schema.BOOLEAN,
             _('Shared.'),
             update_allowed=True, required=True
-        ),
-        REUSE_BD: properties.Schema(
-            properties.Schema.STRING,
-            _('Existing L2P ID in same L3P.'),
-            default=None, update_allowed=False
         )
     }
 
@@ -580,9 +424,6 @@ class PolicyClassifier(gbpresource.GBPResource):
         'direction', 'shared'
     )
 
-    protocols_list = ['tcp', 'udp', 'icmp', None]
-    protocols_list.extend([str(protocol_num) for protocol_num in range(256)])
-
     properties_schema = {
         TENANT_ID: properties.Schema(
             properties.Schema.STRING,
@@ -602,7 +443,7 @@ class PolicyClassifier(gbpresource.GBPResource):
             properties.Schema.STRING,
             _('Protocol of traffic described by the policy classifier.'),
             constraints=[
-                constraints.AllowedValues(protocols_list)
+                constraints.AllowedValues(['tcp', 'udp', 'icmp', None])
             ],
             update_allowed=True
         ),
@@ -1088,36 +929,6 @@ class ExternalPolicy(gbpresource.GBPResource):
 
     def handle_update(self, json_snippet, tmpl_diff, prop_diff):
         if prop_diff:
-            provided_policy_rule_set_list = {}
-            consumed_policy_rule_set_list = {}
-            props_provided_policy_rule_sets = prop_diff.get(
-                'provided_policy_rule_sets', [])
-            props_consumed_policy_rule_sets = prop_diff.get(
-                'consumed_policy_rule_sets', [])
-
-            for prop_prov_policy_rule_set in props_provided_policy_rule_sets:
-                policy_rule_set_id = (
-                    prop_prov_policy_rule_set['policy_rule_set_id'])
-                policy_rule_set_scope = (
-                    prop_prov_policy_rule_set['policy_rule_set_scope'])
-                provided_policy_rule_set_list.update({policy_rule_set_id:
-                                                      policy_rule_set_scope})
-
-            for prop_cons_policy_rule_set in props_consumed_policy_rule_sets:
-                policy_rule_set_id = (
-                    prop_cons_policy_rule_set['policy_rule_set_id'])
-                policy_rule_set_scope = (
-                    prop_cons_policy_rule_set['policy_rule_set_scope'])
-                consumed_policy_rule_set_list.update({policy_rule_set_id:
-                                                      policy_rule_set_scope})
-
-            if provided_policy_rule_set_list:
-                prop_diff['provided_policy_rule_sets'] = (
-                    provided_policy_rule_set_list)
-            if consumed_policy_rule_set_list:
-                prop_diff['consumed_policy_rule_sets'] = (
-                    consumed_policy_rule_set_list)
-
             self.grouppolicy().update_external_policy(
                 self.resource_id, {'external_policy': prop_diff})
 
