@@ -11,9 +11,6 @@
 #    under the License.
 
 import copy
-
-from unittest import mock
-
 import six
 
 from gbpautomation.heat.engine.resources import servicechain
@@ -92,29 +89,14 @@ class ServiceChainNodeTest(HeatTestCase):
 
     def setUp(self):
         super(ServiceChainNodeTest, self).setUp()
-        self.mock_create = mock.patch(
-            'gbpclient.v2_0.client.Client.create_servicechain_node')
-        self.mock_delete = mock.patch(
-            'gbpclient.v2_0.client.Client.delete_servicechain_node')
-        self.mock_show = mock.patch(
-            'gbpclient.v2_0.client.Client.show_servicechain_node')
-        self.mock_update = mock.patch(
-            'gbpclient.v2_0.client.Client.update_servicechain_node')
-        self.mock_create.start()
-        self.mock_delete.start()
-        self.mock_show.start()
-        self.mock_update.start()
+        self.m.StubOutWithMock(gbpclient.Client, 'create_servicechain_node')
+        self.m.StubOutWithMock(gbpclient.Client, 'delete_servicechain_node')
+        self.m.StubOutWithMock(gbpclient.Client, 'show_servicechain_node')
+        self.m.StubOutWithMock(gbpclient.Client, 'update_servicechain_node')
         self.stub_keystoneclient()
 
-    def tearDown(self):
-        self.mock_create.stop()
-        self.mock_delete.stop()
-        self.mock_show.stop()
-        self.mock_update.stop()
-        super(ServiceChainNodeTest, self).tearDown()
-
     def create_servicechain_node(self):
-        call_dict = {
+        gbpclient.Client.create_servicechain_node({
             'servicechain_node': {
                 "name": "test-sc-node",
                 "description": "test service chain node resource",
@@ -122,15 +104,7 @@ class ServiceChainNodeTest(HeatTestCase):
                 "shared": True,
                 "config": "{'name': 'sc_node_config'}"
             }
-        }
-        tdict = {'servicechain_node': {'id': '5678'}}
-        gbpclient.Client.create_servicechain_node.return_value = tdict
-
-        ret_val = gbpclient.Client.create_servicechain_node(call_dict)
-        expected = mock.call(call_dict)
-        _mocked_create = self.mock_create.get_original()[0]
-        _mocked_create.assert_has_calls([expected])
-        self.assertEqual(tdict, ret_val)
+        }).AndReturn({'servicechain_node': {'id': '5678'}})
 
         snippet = template_format.parse(servicechain_node_template)
         self.stack = utils.parse_stack(snippet)
@@ -141,11 +115,13 @@ class ServiceChainNodeTest(HeatTestCase):
 
     def test_create(self):
         rsrc = self.create_servicechain_node()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
+        self.m.VerifyAll()
 
     def test_create_failed(self):
-        call_dict = {
+        gbpclient.Client.create_servicechain_node({
             'servicechain_node': {
                 "name": "test-sc-node",
                 "description": "test service chain node resource",
@@ -153,9 +129,8 @@ class ServiceChainNodeTest(HeatTestCase):
                 "shared": True,
                 "config": "{'name': 'sc_node_config'}"
             }
-        }
-        exc = servicechain.NeutronClientException()
-        gbpclient.Client.create_servicechain_node.side_effect = exc
+        }).AndRaise(servicechain.NeutronClientException())
+        self.m.ReplayAll()
 
         snippet = template_format.parse(servicechain_node_template)
         self.stack = utils.parse_stack(snippet)
@@ -167,115 +142,84 @@ class ServiceChainNodeTest(HeatTestCase):
         error = self.assertRaises(exception.ResourceFailure,
                                   scheduler.TaskRunner(rsrc.create))
         self.assertEqual(
-            'NeutronClientException: resources.servicechain_node: '
+            'NeutronClientException: '
             'An unknown exception occurred.',
             six.text_type(error))
         self.assertEqual((rsrc.CREATE, rsrc.FAILED), rsrc.state)
-
-        expected = mock.call(call_dict)
-        _mocked_create = self.mock_create.get_original()[0]
-        _mocked_create.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete(self):
-        exc = servicechain.NeutronClientException(status_code=404)
-        gbpclient.Client.show_servicechain_node.side_effect = exc
+        gbpclient.Client.delete_servicechain_node('5678')
+        gbpclient.Client.show_servicechain_node('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=404))
 
         rsrc = self.create_servicechain_node()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
         self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_show = self.mock_show.get_original()[0]
-        _mocked_show.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete_already_gone(self):
-        exc = servicechain.NeutronClientException(status_code=404)
-        gbpclient.Client.delete_servicechain_node.side_effect = exc
+        gbpclient.Client.delete_servicechain_node('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=404))
 
         rsrc = self.create_servicechain_node()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
         self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_delete = self.mock_delete.get_original()[0]
-        _mocked_delete.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete_failed(self):
-        exc = servicechain.NeutronClientException(status_code=400)
-        gbpclient.Client.delete_servicechain_node.side_effect = exc
+        gbpclient.Client.delete_servicechain_node('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=400))
 
         rsrc = self.create_servicechain_node()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         error = self.assertRaises(exception.ResourceFailure,
                                   scheduler.TaskRunner(rsrc.delete))
         self.assertEqual(
-            'NeutronClientException: resources.servicechain_node: '
+            'NeutronClientException: '
             'An unknown exception occurred.',
             six.text_type(error))
         self.assertEqual((rsrc.DELETE, rsrc.FAILED), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_delete = self.mock_delete.get_original()[0]
-        _mocked_delete.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_update(self):
         rsrc = self.create_servicechain_node()
-        call_dict = {'servicechain_node': {'name': 'node_update'}}
+        gbpclient.Client.update_servicechain_node(
+            '5678', {'servicechain_node': {'name': 'node_update'}})
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
 
         update_template = copy.deepcopy(rsrc.t)
-        update_template._properties['name'] = 'node_update'
+        update_template['Properties']['name'] = 'node_update'
         scheduler.TaskRunner(rsrc.update, update_template)()
 
-        expected = mock.call('5678', call_dict)
-        _mocked_update = self.mock_update.get_original()[0]
-        _mocked_update.assert_has_calls([expected])
+        self.m.VerifyAll()
 
 
 class ServiceChainSpecTest(HeatTestCase):
 
     def setUp(self):
         super(ServiceChainSpecTest, self).setUp()
-        self.mock_create = mock.patch(
-            'gbpclient.v2_0.client.Client.create_servicechain_spec')
-        self.mock_delete = mock.patch(
-            'gbpclient.v2_0.client.Client.delete_servicechain_spec')
-        self.mock_show = mock.patch(
-            'gbpclient.v2_0.client.Client.show_servicechain_spec')
-        self.mock_update = mock.patch(
-            'gbpclient.v2_0.client.Client.update_servicechain_spec')
-        self.mock_create.start()
-        self.mock_delete.start()
-        self.mock_show.start()
-        self.mock_update.start()
+        self.m.StubOutWithMock(gbpclient.Client, 'create_servicechain_spec')
+        self.m.StubOutWithMock(gbpclient.Client, 'delete_servicechain_spec')
+        self.m.StubOutWithMock(gbpclient.Client, 'show_servicechain_spec')
+        self.m.StubOutWithMock(gbpclient.Client, 'update_servicechain_spec')
         self.stub_keystoneclient()
 
-    def tearDown(self):
-        self.mock_create.stop()
-        self.mock_delete.stop()
-        self.mock_show.stop()
-        self.mock_update.stop()
-        super(ServiceChainSpecTest, self).tearDown()
-
     def create_servicechain_spec(self):
-        call_dict = {
+        gbpclient.Client.create_servicechain_spec({
             "servicechain_spec": {
                 "name": "test-sc-spec",
                 "description": "test service chain spec resource",
                 "shared": True,
                 "nodes": ["1234", "7890"]
             }
-        }
-        tdict = {'servicechain_spec': {'id': '5678'}}
-        gbpclient.Client.create_servicechain_spec.return_value = tdict
-
-        ret_val = gbpclient.Client.create_servicechain_spec(call_dict)
-        expected = mock.call(call_dict)
-        _mocked_create = self.mock_create.get_original()[0]
-        _mocked_create.assert_has_calls([expected])
-        self.assertEqual(tdict, ret_val)
+        }).AndReturn({'servicechain_spec': {'id': '5678'}})
 
         snippet = template_format.parse(servicechain_spec_template)
         self.stack = utils.parse_stack(snippet)
@@ -286,20 +230,21 @@ class ServiceChainSpecTest(HeatTestCase):
 
     def test_create(self):
         rsrc = self.create_servicechain_spec()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
+        self.m.VerifyAll()
 
     def test_create_failed(self):
-        call_dict = {
+        gbpclient.Client.create_servicechain_spec({
             'servicechain_spec': {
                 "name": "test-sc-spec",
                 "description": "test service chain spec resource",
                 "shared": True,
                 "nodes": ["1234", "7890"]
             }
-        }
-        exc = servicechain.NeutronClientException()
-        gbpclient.Client.create_servicechain_spec.side_effect = exc
+        }).AndRaise(servicechain.NeutronClientException())
+        self.m.ReplayAll()
 
         snippet = template_format.parse(servicechain_spec_template)
         self.stack = utils.parse_stack(snippet)
@@ -311,100 +256,77 @@ class ServiceChainSpecTest(HeatTestCase):
         error = self.assertRaises(exception.ResourceFailure,
                                   scheduler.TaskRunner(rsrc.create))
         self.assertEqual(
-            'NeutronClientException: resources.servicechain_spec: '
+            'NeutronClientException: '
             'An unknown exception occurred.',
             six.text_type(error))
         self.assertEqual((rsrc.CREATE, rsrc.FAILED), rsrc.state)
-
-        expected = mock.call(call_dict)
-        _mocked_create = self.mock_create.get_original()[0]
-        _mocked_create.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete(self):
-        exc = servicechain.NeutronClientException(status_code=404)
-        gbpclient.Client.show_servicechain_spec.side_effect = exc
+        gbpclient.Client.delete_servicechain_spec('5678')
+        gbpclient.Client.show_servicechain_spec('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=404))
 
         rsrc = self.create_servicechain_spec()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
         self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_show = self.mock_show.get_original()[0]
-        _mocked_show.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete_already_gone(self):
-        exc = servicechain.NeutronClientException(status_code=404)
-        gbpclient.Client.delete_servicechain_spec.side_effect = exc
+        gbpclient.Client.delete_servicechain_spec('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=404))
 
         rsrc = self.create_servicechain_spec()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
         self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_delete = self.mock_delete.get_original()[0]
-        _mocked_delete.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete_failed(self):
-        exc = servicechain.NeutronClientException(status_code=400)
-        gbpclient.Client.delete_servicechain_spec.side_effect = exc
+        gbpclient.Client.delete_servicechain_spec('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=400))
 
         rsrc = self.create_servicechain_spec()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         error = self.assertRaises(exception.ResourceFailure,
                                   scheduler.TaskRunner(rsrc.delete))
         self.assertEqual(
-            'NeutronClientException: resources.servicechain_spec: '
+            'NeutronClientException: '
             'An unknown exception occurred.',
             six.text_type(error))
         self.assertEqual((rsrc.DELETE, rsrc.FAILED), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_delete = self.mock_delete.get_original()[0]
-        _mocked_delete.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_update(self):
         rsrc = self.create_servicechain_spec()
-        call_dict = {'servicechain_spec': {'name': 'spec_update'}}
+        gbpclient.Client.update_servicechain_spec(
+            '5678', {'servicechain_spec': {'name': 'spec_update'}})
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
 
         update_template = copy.deepcopy(rsrc.t)
-        update_template._properties['name'] = 'spec_update'
+        update_template['Properties']['name'] = 'spec_update'
         scheduler.TaskRunner(rsrc.update, update_template)()
 
-        expected = mock.call('5678', call_dict)
-        _mocked_update = self.mock_update.get_original()[0]
-        _mocked_update.assert_has_calls([expected])
+        self.m.VerifyAll()
 
 
 class ServiceProfileTest(HeatTestCase):
 
     def setUp(self):
         super(ServiceProfileTest, self).setUp()
-        self.mock_create = mock.patch(
-            'gbpclient.v2_0.client.Client.create_service_profile')
-        self.mock_delete = mock.patch(
-            'gbpclient.v2_0.client.Client.delete_service_profile')
-        self.mock_show = mock.patch(
-            'gbpclient.v2_0.client.Client.show_service_profile')
-        self.mock_update = mock.patch(
-            'gbpclient.v2_0.client.Client.update_service_profile')
-        self.mock_create.start()
-        self.mock_delete.start()
-        self.mock_show.start()
-        self.mock_update.start()
+        self.m.StubOutWithMock(gbpclient.Client, 'create_service_profile')
+        self.m.StubOutWithMock(gbpclient.Client, 'delete_service_profile')
+        self.m.StubOutWithMock(gbpclient.Client, 'show_service_profile')
+        self.m.StubOutWithMock(gbpclient.Client, 'update_service_profile')
         self.stub_keystoneclient()
 
-    def tearDown(self):
-        self.mock_create.stop()
-        self.mock_delete.stop()
-        self.mock_show.stop()
-        self.mock_update.stop()
-        super(ServiceProfileTest, self).tearDown()
-
     def create_service_profile(self):
-        call_dict = {
+        gbpclient.Client.create_service_profile({
             'service_profile': {
                 "name": "test-svc-profile",
                 "description": "test service profile resource",
@@ -414,15 +336,7 @@ class ServiceProfileTest(HeatTestCase):
                 "service_flavor": "test flavor",
                 "shared": True
             }
-        }
-        tdict = {'service_profile': {'id': '5678'}}
-        gbpclient.Client.create_service_profile.return_value = tdict
-
-        ret_val = gbpclient.Client.create_service_profile(call_dict)
-        expected = mock.call(call_dict)
-        _mocked_create = self.mock_create.get_original()[0]
-        _mocked_create.assert_has_calls([expected])
-        self.assertEqual(tdict, ret_val)
+        }).AndReturn({'service_profile': {'id': '5678'}})
 
         snippet = template_format.parse(service_profile_template)
         self.stack = utils.parse_stack(snippet)
@@ -432,11 +346,13 @@ class ServiceProfileTest(HeatTestCase):
 
     def test_create(self):
         rsrc = self.create_service_profile()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
+        self.m.VerifyAll()
 
     def test_create_failed(self):
-        call_dict = {
+        gbpclient.Client.create_service_profile({
             'service_profile': {
                 "name": "test-svc-profile",
                 "description": "test service profile resource",
@@ -446,9 +362,8 @@ class ServiceProfileTest(HeatTestCase):
                 "service_flavor": "test flavor",
                 "shared": True
             }
-        }
-        exc = servicechain.NeutronClientException()
-        gbpclient.Client.create_service_profile.side_effect = exc
+        }).AndRaise(servicechain.NeutronClientException())
+        self.m.ReplayAll()
 
         snippet = template_format.parse(service_profile_template)
         self.stack = utils.parse_stack(snippet)
@@ -460,68 +375,60 @@ class ServiceProfileTest(HeatTestCase):
         error = self.assertRaises(exception.ResourceFailure,
                                   scheduler.TaskRunner(rsrc.create))
         self.assertEqual(
-            'NeutronClientException: resources.service_profile: '
+            'NeutronClientException: '
             'An unknown exception occurred.',
             six.text_type(error))
         self.assertEqual((rsrc.CREATE, rsrc.FAILED), rsrc.state)
-
-        expected = mock.call(call_dict)
-        _mocked_create = self.mock_create.get_original()[0]
-        _mocked_create.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete(self):
-        exc = servicechain.NeutronClientException(status_code=404)
-        gbpclient.Client.show_service_profile.side_effect = exc
+        gbpclient.Client.delete_service_profile('5678')
+        gbpclient.Client.show_service_profile('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=404))
 
         rsrc = self.create_service_profile()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
         self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_show = self.mock_show.get_original()[0]
-        _mocked_show.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete_already_gone(self):
-        exc = servicechain.NeutronClientException(status_code=404)
-        gbpclient.Client.delete_service_profile.side_effect = exc
+        gbpclient.Client.delete_service_profile('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=404))
 
         rsrc = self.create_service_profile()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         scheduler.TaskRunner(rsrc.delete)()
         self.assertEqual((rsrc.DELETE, rsrc.COMPLETE), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_delete = self.mock_delete.get_original()[0]
-        _mocked_delete.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_delete_failed(self):
-        exc = servicechain.NeutronClientException(status_code=400)
-        gbpclient.Client.delete_service_profile.side_effect = exc
+        gbpclient.Client.delete_service_profile('5678').AndRaise(
+            servicechain.NeutronClientException(status_code=400))
 
         rsrc = self.create_service_profile()
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
         error = self.assertRaises(exception.ResourceFailure,
                                   scheduler.TaskRunner(rsrc.delete))
         self.assertEqual(
-            'NeutronClientException: resources.service_profile: '
+            'NeutronClientException: '
             'An unknown exception occurred.',
             six.text_type(error))
         self.assertEqual((rsrc.DELETE, rsrc.FAILED), rsrc.state)
-
-        expected = mock.call('5678')
-        _mocked_delete = self.mock_delete.get_original()[0]
-        _mocked_delete.assert_has_calls([expected])
+        self.m.VerifyAll()
 
     def test_update(self):
         rsrc = self.create_service_profile()
-        call_dict = {'service_profile': {'name': 'profile_update'}}
+        gbpclient.Client.update_service_profile(
+            '5678', {'service_profile': {'name': 'profile_update'}})
+        self.m.ReplayAll()
         scheduler.TaskRunner(rsrc.create)()
 
         update_template = copy.deepcopy(rsrc.t)
-        update_template._properties['name'] = 'profile_update'
+        update_template['Properties']['name'] = 'profile_update'
         scheduler.TaskRunner(rsrc.update, update_template)()
 
-        expected = mock.call('5678', call_dict)
-        _mocked_update = self.mock_update.get_original()[0]
-        _mocked_update.assert_has_calls([expected])
+        self.m.VerifyAll()
